<?php
require_once 'config.php';

function registerUser($name, $phone, $password) {
    global $mysqli;

    // Проверка, существует ли пользователь с таким номером телефона
    $stmt = $mysqli->prepare("SELECT id FROM users WHERE phone = ?");
    $stmt->bind_param("s", $phone);
    $stmt->execute();
    $result = $stmt->get_result();
    if ($result->num_rows > 0) {
        return "Пользователь с таким номером телефона уже существует";
    }
    $stmt->close();

    // Хеширование пароля
    $hashed_password = password_hash($password, PASSWORD_DEFAULT);

    // Вставка нового пользователя в базу данных
    $stmt = $mysqli->prepare("INSERT INTO users (name, phone, password) VALUES (?, ?, ?)");
    $stmt->bind_param("sss", $name, $phone, $hashed_password);
    if ($stmt->execute()) {
        $user_id = $mysqli->insert_id;
        $auth_token = generateAuthToken();

        // Обновляем auth_token в базе данных
        $update_stmt = $mysqli->prepare("UPDATE users SET auth_token = ? WHERE id = ?");
        $update_stmt->bind_param("si", $auth_token, $user_id);
        $update_stmt->execute();

        setAuthCookie($user_id, $auth_token);
        $_SESSION['user_id'] = $user_id;  // Устанавливаем сессию
        logAction($user_id, 'registration');
        return true;
    } else {
        return "Ошибка при регистрации пользователя";
    }
}

function loginUser($phone, $password) {
    global $mysqli;

    // Проверяем, существует ли пользователь с таким номером телефона
    $stmt = $mysqli->prepare("SELECT id, password FROM users WHERE phone = ?");
    $stmt->bind_param("s", $phone);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows === 0) {
        return "Пользователь с таким номером телефона не найден";
    }

    $user = $result->fetch_assoc();

    // Проверяем пароль
    if (password_verify($password, $user['password'])) {
        $user_id = $user['id'];
        $auth_token = generateAuthToken();

        // Обновляем auth_token в базе данных
        $update_stmt = $mysqli->prepare("UPDATE users SET auth_token = ? WHERE id = ?");
        $update_stmt->bind_param("si", $auth_token, $user_id);
        $update_stmt->execute();

        setAuthCookie($user_id, $auth_token);
        $_SESSION['user_id'] = $user_id;  // Устанавливаем сессию
        logAction($user_id, 'login');
        return $user_id;
    } else {
        return "Неверный пароль";
    }
}

function generateAuthToken() {
    return bin2hex(random_bytes(32));
}

function setAuthCookie($user_id, $auth_token) {
    $expiry = time() + (90 * 24 * 60 * 60); // 90 дней
    setcookie('user_id', $user_id, $expiry, '/', '', true, true);
    setcookie('auth_token', $auth_token, $expiry, '/', '', true, true);
}

function validateAuthCookie($user_id, $auth_token) {
    global $mysqli;
    $stmt = $mysqli->prepare("SELECT id FROM users WHERE id = ? AND auth_token = ?");
    $stmt->bind_param("is", $user_id, $auth_token);
    $stmt->execute();
    $result = $stmt->get_result();
    return $result->num_rows > 0;
}



function logAction($user_id, $action) {
    $log_file = __DIR__ . '/../logs/mainLogs.php';
    $log_entry = date('Y-m-d H:i:s') . " - User ID: $user_id - Action: $action\n";
    file_put_contents($log_file, $log_entry, FILE_APPEND);
}

function logoutUser() {
    global $mysqli;

    if (isset($_COOKIE['user_id'])) {
        $user_id = $_COOKIE['user_id'];

        // Очищаем auth_token в базе данных
        $stmt = $mysqli->prepare("UPDATE users SET auth_token = NULL WHERE id = ?");
        $stmt->bind_param("i", $user_id);
        $stmt->execute();

        logAction($user_id, 'logout');
    }

    // Удаляем куки
    setcookie('user_id', '', time() - 3600, '/', '', true, true);
    setcookie('auth_token', '', time() - 3600, '/', '', true, true);

    // Удаляем сессию
    session_unset();
    session_destroy();
}

// Новая функция для обработки действия выхода
function handleLogout() {
    logoutUser();
    header("Location: /login.php");
    exit();
}
